@@ -14,11 +14,15 @@ param_pwscf_old_file = 'param-pyridine-pwscf-old.json'
 param_gaussian_file = 'param-pyridine-gaussian.json'
 param_siesta_file = 'param-pyridine-siesta.json'
 param_cp2k_file = 'param-pyridine-cp2k.json'
-param_cp2k_file_v1 = 'param-pyridine-cp2k-choose-vdw.json'
+param_cp2k_file_exinput = 'param-mgo-cp2k-exinput.json'
+ref_cp2k_file_input = 'cp2k_test_ref.inp'
+ref_cp2k_file_exinput = 'cp2k_test_exref.inp'
 machine_file = 'machine-local.json'
 machine_file_v1 = 'machine-local-v1.json'
 param_diy_file = 'param-mg-vasp-diy.json'
 param_pwmat_file = 'param-pyridine-pwmat.json'
+param_abacus_file = 'param-pyridine-abacus.json'
+param_abacus_post_file = 'param-methane-abacus.json'
 
 def my_file_cmp(test, f0, f1):
     with open(f0) as fp0 :
