@@ -13,10 +13,13 @@ from .context import param_file
 from .context import param_old_file
 from .context import param_pwscf_file
 from .context import param_pwscf_old_file
+from .context import param_abacus_post_file
 from .context import param_siesta_file
 from .context import param_gaussian_file
 from .context import param_cp2k_file
-from .context import param_cp2k_file_v1
+from .context import param_cp2k_file_exinput
+from .context import ref_cp2k_file_input
+from .context import ref_cp2k_file_exinput
 from .context import machine_file
 from .context import param_diy_file
 from .context import make_kspacing_kpoints
@@ -129,65 +132,6 @@ gaussian_input_ref="""%nproc=14
 DPGEN
 """
 
-cp2k_input_ref="\
-&GLOBAL\n\
-PROJECT DPGEN\n\
-&END GLOBAL\n\
-&FORCE_EVAL\n\
-METHOD QS\n\
-STRESS_TENSOR ANALYTICAL\n\
-&DFT\n\
-BASIS_SET_FILE_NAME ./cp2k_basis_pp_file/BASIS_MOLOPT\n\
-POTENTIAL_FILE_NAME ./cp2k_basis_pp_file/GTH_POTENTIALS\n\
-CHARGE 0\n\
-UKS F\n\
-MULTIPLICITY 1\n\
-&MGRID\n\
-CUTOFF 400\n\
-REL_CUTOFF 50\n\
-NGRIDS 4\n\
-&END MGRID\n\
-&QS\n\
-EPS_DEFAULT 1.0E-12\n\
-&END QS\n\
-&SCF\n\
-SCF_GUESS ATOMIC\n\
-EPS_SCF 1.0E-6\n\
-MAX_SCF 50\n\
-&OT\n\
-MINIMIZER DIIS\n\
-PRECONDITIONER FULL_SINGLE_INVERSE\n\
-&END OT\n\
-&END SCF\n\
-&XC\n\
-&XC_FUNCTIONAL PBE\n\
-&END XC_FUNCTIONAL\n\
-&END XC\n\
-&END DFT\n\
-&SUBSYS\n\
-&CELL\n\
-&END CELL\n\
-&COORD\n\
-@include coord.xyz\n\
-&END COORD\n\
-&KIND H\n\
-BASIS_SET DZVP-MOLOPT-GTH\n\
-POTENTIAL GTH-PBE-q1\n\
-&END KIND\n\
-&KIND C\n\
-BASIS_SET DZVP-MOLOPT-GTH\n\
-POTENTIAL GTH-PBE-q4\n\
-&END KIND\n\
-&KIND N\n\
-BASIS_SET DZVP-MOLOPT-GTH\n\
-POTENTIAL GTH-PBE-q5\n\
-&END KIND\n\
-&END SUBSYS\n\
-&PRINT\n\
-&FORCES ON\n\
-&END FORCES\n\
-&END PRINT\n\
-&END FORCE_EVAL\n";
 
 pwmat_input_ref = "4 1\n\
 in.atom=atom.config\n\
@@ -205,7 +149,25 @@ IN.PSP1 = C.SG15.PBE.UPF\n\
 IN.PSP2 = H.SG15.PBE.UPF\n\
 IN.PSP3 = N.SG15.PBE.UPF\n";
 
+abacus_input_ref = "INPUT_PARAMETERS\n\
+ntype 2\n\
+pseudo_dir ./\n\
+ecutwfc 80.000000\n\
+mixing_type pulay\n\
+mixing_beta 0.400000\n\
+symmetry 1\n\
+nbands 5.000000\n\
+nspin 1\n\
+ks_solver cg\n\
+smearing fixed\n\
+sigma 0.001000\n\
+force 1\n\
+stress 1\n"
 
+abacus_kpt_ref = "K_POINTS\n\
+0\n\
+Gamma\n\
+1 1 1 0 0 0\n"
 
 
 def _box2lmpbox(orig, box) :
@@ -439,6 +401,26 @@ def _check_pwscf_input_head(testCase, idx) :
         lines = lines[:idx]
         testCase.assertEqual(('\n'.join(lines)).strip(), pwscf_input_ref.strip())
 
+def _check_abacus_input(testCase, idx) :
+    fp_path = os.path.join('iter.%06d' % idx, '02.fp')
+    tasks = glob.glob(os.path.join(fp_path, 'task.*'))
+    for ii in tasks :
+        ifile = os.path.join(ii, 'INPUT')
+        testCase.assertTrue(os.path.isfile(ifile))
+        with open(ifile) as fp:
+            lines = fp.read().split('\n')
+        testCase.assertEqual(('\n'.join(lines)).strip(), abacus_input_ref.strip())
+
+def _check_abacus_kpt(testCase, idx) :
+    fp_path = os.path.join('iter.%06d' % idx, '02.fp')
+    tasks = glob.glob(os.path.join(fp_path, 'task.*'))
+    for ii in tasks :
+        ifile = os.path.join(ii, 'KPT')
+        testCase.assertTrue(os.path.isfile(ifile))
+        with open(ifile) as fp:
+            lines = fp.read().split('\n')
+        testCase.assertEqual(('\n'.join(lines)).strip(), abacus_kpt_ref.strip())
+
 def _check_siesta_input_head(testCase, idx) :
     fp_path = os.path.join('iter.%06d' % idx, '02.fp')
     tasks = glob.glob(os.path.join(fp_path, 'task.*'))
@@ -469,7 +451,7 @@ def _check_gaussian_input_head(testCase, idx) :
         testCase.assertEqual(('\n'.join(lines)).strip(), gaussian_input_ref.strip())
 
 
-def _check_cp2k_input_head(testCase, idx) :
+def _check_cp2k_input_head(testCase, idx, ref_out) :
     fp_path = os.path.join('iter.%06d' % idx, '02.fp')
     tasks = glob.glob(os.path.join(fp_path, 'task.*'))
     for ii in tasks :
@@ -483,7 +465,7 @@ def _check_cp2k_input_head(testCase, idx) :
             if '&END CELL' in jj :
                 cell_end_idx = idx
         lines_check = lines[:cell_start_idx+1] + lines[cell_end_idx:]
-        testCase.assertEqual(('\n'.join(lines_check)).strip(), cp2k_input_ref.strip())
+        testCase.assertEqual(('\n'.join(lines_check)).strip(), ref_out.strip())
 
 
 
@@ -501,6 +483,7 @@ def _check_pwmat_input(testCase, idx):
 
 class TestMakeFPPwscf(unittest.TestCase):
     def test_make_fp_pwscf(self):
+        setUpModule()
         if os.path.isdir('iter.000000') :
             shutil.rmtree('iter.000000')
         with open (param_pwscf_file, 'r') as fp :
@@ -527,6 +510,7 @@ class TestMakeFPPwscf(unittest.TestCase):
         shutil.rmtree('iter.000000')
 
     def test_make_fp_pwscf_old(self):
+        setUpModule()
         if os.path.isdir('iter.000000') :
             shutil.rmtree('iter.000000')
         with open (param_pwscf_old_file, 'r') as fp :
@@ -552,8 +536,38 @@ class TestMakeFPPwscf(unittest.TestCase):
         _check_potcar(self, 0, jdata['fp_pp_path'], jdata['fp_pp_files'])
         shutil.rmtree('iter.000000')
 
+class TestMakeFPABACUS(unittest.TestCase):
+    def test_make_fp_abacus(self):
+        setUpModule()
+        if os.path.isdir('iter.000000') :
+            shutil.rmtree('iter.000000')
+        with open (param_abacus_post_file, 'r') as fp :
+            jdata = json.load (fp)
+        with open (machine_file, 'r') as fp:
+            mdata = json.load (fp)
+        md_descript = []
+        nsys = 2
+        nmd = 3
+        n_frame = 10
+        for ii in range(nsys) :
+            tmp = []
+            for jj in range(nmd) :
+                tmp.append(np.arange(0, 0.29, 0.29/10))
+            md_descript.append(tmp)
+        atom_types = [0, 0, 0, 0, 1]
+        type_map = jdata['type_map']
+        _make_fake_md(0, md_descript, atom_types, type_map)
+        make_fp(0, jdata, {})
+        _check_sel(self, 0, jdata['fp_task_max'], jdata['model_devi_f_trust_lo'], jdata['model_devi_f_trust_hi'])
+        _check_poscars(self, 0, jdata['fp_task_max'], jdata['type_map'])
+        _check_abacus_input(self, 0)
+        _check_abacus_kpt(self, 0)
+        _check_potcar(self, 0, jdata['fp_pp_path'], jdata['fp_pp_files'])
+        shutil.rmtree('iter.000000')
+
 class TestMakeFPSIESTA(unittest.TestCase):
     def test_make_fp_siesta(self):
+        setUpModule()
         if os.path.isdir('iter.000000') :
             shutil.rmtree('iter.000000')
         with open (param_siesta_file, 'r') as fp :
@@ -581,6 +595,7 @@ class TestMakeFPSIESTA(unittest.TestCase):
 
 class TestMakeFPVasp(unittest.TestCase):
     def test_make_fp_vasp(self):
+        setUpModule()
         if os.path.isdir('iter.000000') :
             shutil.rmtree('iter.000000')
         with open (param_file, 'r') as fp :
@@ -611,6 +626,7 @@ class TestMakeFPVasp(unittest.TestCase):
         shutil.rmtree('iter.000000')
 
     def test_make_fp_vasp_old(self):
+        setUpModule()
         if os.path.isdir('iter.000000') :
             shutil.rmtree('iter.000000')
         with open (param_old_file, 'r') as fp :
@@ -673,6 +689,7 @@ class TestMakeFPVasp(unittest.TestCase):
 
     def test_make_fp_vasp_from_incar(self):
         ## Verify if user chooses to diy VASP INCAR totally.
+        setUpModule()
         if os.path.isdir('iter.000000') :
             shutil.rmtree('iter.000000')
         with open (param_diy_file, 'r') as fp :
@@ -706,6 +723,7 @@ class TestMakeFPVasp(unittest.TestCase):
 
     def test_make_fp_vasp_ele_temp(self):
         ## Verify if user chooses to diy VASP INCAR totally.
+        setUpModule()
         if os.path.isdir('iter.000000') :
             shutil.rmtree('iter.000000')
         with open (param_diy_file, 'r') as fp :
@@ -741,6 +759,7 @@ class TestMakeFPVasp(unittest.TestCase):
 
 class TestMakeFPGaussian(unittest.TestCase):
     def make_fp_gaussian(self, multiplicity="auto"):
+        setUpModule()
         if os.path.isdir('iter.000000') :
             shutil.rmtree('iter.000000')
         with open (param_gaussian_file, 'r') as fp :
@@ -791,6 +810,7 @@ class TestMakeFPGaussian(unittest.TestCase):
 
 class TestMakeFPCP2K(unittest.TestCase):
     def test_make_fp_cp2k(self):
+        setUpModule()
         if os.path.isdir('iter.000000') :
             shutil.rmtree('iter.000000')
         with open (param_cp2k_file, 'r') as fp :
@@ -812,13 +832,45 @@ class TestMakeFPCP2K(unittest.TestCase):
         make_fp(0, jdata, {})
         _check_sel(self, 0, jdata['fp_task_max'], jdata['model_devi_f_trust_lo'], jdata['model_devi_f_trust_hi'])
         _check_poscars(self, 0, jdata['fp_task_max'], jdata['type_map'])
-        _check_cp2k_input_head(self, 0)
+        with open(ref_cp2k_file_input, 'r') as f:
+            cp2k_input_ref = ''.join(f.readlines())
+        _check_cp2k_input_head(self, 0, cp2k_input_ref)
+        _check_potcar(self, 0, jdata['fp_pp_path'], jdata['fp_pp_files'])
+        shutil.rmtree('iter.000000')
+    def test_make_fp_cp2k_exinput(self):
+        setUpModule()
+        if os.path.isdir('iter.000000') :
+            shutil.rmtree('iter.000000')
+        with open (param_cp2k_file_exinput, 'r') as fp :
+            jdata = json.load (fp)
+        with open (machine_file, 'r') as fp:
+            mdata = json.load (fp)
+        md_descript = []
+        nsys = 2
+        nmd = 3
+        n_frame = 10
+        for ii in range(nsys) :
+            tmp = []
+            for jj in range(nmd) :
+                tmp.append(np.arange(0, 0.29, 0.29/10))
+            md_descript.append(tmp)
+        atom_types = [0, 1, 2, 2, 0, 1]
+        type_map = jdata['type_map']
+        _make_fake_md(0, md_descript, atom_types, type_map)
+        make_fp(0, jdata, {})
+        _check_sel(self, 0, jdata['fp_task_max'], jdata['model_devi_f_trust_lo'], jdata['model_devi_f_trust_hi'])
+        _check_poscars(self, 0, jdata['fp_task_max'], jdata['type_map'])
+        with open(ref_cp2k_file_exinput, 'r') as f:
+            cp2k_exinput_ref = ''.join(f.readlines())
+        _check_cp2k_input_head(self, 0, cp2k_exinput_ref)
         _check_potcar(self, 0, jdata['fp_pp_path'], jdata['fp_pp_files'])
         shutil.rmtree('iter.000000')
 
 
+
 class TestMakeFPPWmat(unittest.TestCase):
     def test_make_fp_pwmat(self):
+        setUpModule()
         if os.path.isdir('iter.000000') :
             shutil.rmtree('iter.000000')
         with open (param_pwmat_file, 'r') as fp :
